@@ -31,6 +31,11 @@ class ERC721(Generic[TERC721], BaseContract[TERC721]):
         """
         Get metadata for a token
 
+        ```python
+        nft = contract.get(0)
+        print(nft)
+        ```
+
         :param token_id: token ID of the token to get the metadata for
         :return: the metadata for the token and its owner
         """
@@ -49,6 +54,11 @@ class ERC721(Generic[TERC721], BaseContract[TERC721]):
         """
         Get the metadata of all tokens in the contract
 
+        ```python
+        nfts = contract.get_all()
+        print(nfts)
+        ```
+
         :param query_params: optionally define a QueryAllParams instance to narrow the metadata query to specific tokens
         :return: the metadata of all tokens in the contract
         """
@@ -69,16 +79,32 @@ class ERC721(Generic[TERC721], BaseContract[TERC721]):
         """
         Get the metadata of all tokens owned by a specific address
 
+        ```python
+        nfts = contract.get_owned("{{wallet_address}}")
+        print(nfts)
+        ```
+
         :param address: the address to get the metadata for
         :return: the metadata of all tokens owned by the address
         """
+
+        token_ids = self.get_owned_token_ids(address)
+        return [self.get(token_id) for token_id in token_ids]
+
+    def get_owned_token_ids(self, address: str = "") -> List[int]:
+        """
+        Get the token IDs owned by a specific address
+
+        :param address: the address to get the token IDs for
+        :return: the token IDs owned by the address
+        """
+
         owner = address if address else self._contract_wrapper.get_signer_address()
         balance = self._contract_wrapper._contract_abi.balance_of.call(owner)
-        token_ids = [
+        return [
             self._contract_wrapper._contract_abi.token_of_owner_by_index.call(owner, i)
             for i in range(balance)
         ]
-        return [self.get(token_id) for token_id in token_ids]
 
     def owner_of(self, token_id: int) -> str:
         """
@@ -114,6 +140,11 @@ class ERC721(Generic[TERC721], BaseContract[TERC721]):
         """
         Get the token balance of a specific address
 
+        ```python
+        balance = contract.balance_of("{{wallet_address}}")
+        print(balance)
+        ```
+
         :param address: the address to get the token balance of
         """
 
@@ -155,6 +186,13 @@ class ERC721(Generic[TERC721], BaseContract[TERC721]):
         """
         Transfer a specified token from the connected wallet to a specified address.
 
+        ```python
+        to = "{{wallet_address}}"
+        token_id = 0
+
+        receipt = contract.transfer(to, token_id)
+        ```
+
         :param to: wallet address to transfer the tokens to
         :param token_id: the specific token ID to transfer
         :returns: transaction receipt of the transfer
